### R code from vignette source 'iSubpathwayMiner.Rnw'

###################################################
### code chunk number 1: iSubpathwayMiner.Rnw:49-50
###################################################
library(iSubpathwayMiner)


###################################################
### code chunk number 2: iSubpathwayMiner.Rnw:53-60
###################################################
#get path of the KGML files
path<-paste(system.file(package="iSubpathwayMiner"),
"/localdata/kgml/metabolic/ec/",sep="")
#convert pathways to a list in R
pList<-getPathway(path,c("ec00010.xml","ec00020.xml"))
#convert metabolic pathways to graphs
gmList<-getMetabolicGraph(pList)


###################################################
### code chunk number 3: overview1
###################################################
#visualize
plotGraph(gmList[[1]])


###################################################
### code chunk number 4: iSubpathwayMiner.Rnw:70-71
###################################################
getOrgAndIdType()


###################################################
### code chunk number 5: iSubpathwayMiner.Rnw:75-86
###################################################
#To do this, let us generate an example of gene sets:
geneList<-getExample(geneNumber=1000,compoundNumber=0)
#see a part of the set. 
#organism:human (hsa)
#identifier type:Entrez Gene IDs (ncbi-geneid)
geneList[1:5]
#annotate the sets to pathways 
#evaluate the enrichment significance of pathways
ann<-identifyGraph(geneList,gmList)
#print the results to screen
printGraph(ann)


###################################################
### code chunk number 6: iSubpathwayMiner.Rnw:101-106
###################################################
#get path of the KGML files
path<-paste(system.file(package="iSubpathwayMiner"),
"/localdata/kgml/metabolic/ec/",sep="")
#convert pathways to a list in R
p<-getPathway(path,c("ec00010.xml","ec00020.xml"))


###################################################
### code chunk number 7: iSubpathwayMiner.Rnw:119-126
###################################################
#get path of the KGML files
path<-paste(system.file(package="iSubpathwayMiner"),
"/localdata/kgml/metabolic/ec/",sep="")
#convert pathways to a list in R
p<-getPathway(path,c("ec00010.xml"))
#convert metabolic pathways to graphs
gm<-getMetabolicGraph(p)


###################################################
### code chunk number 8: getMetabolicGraph1
###################################################
#name of graph gm[[1]]
gm[[1]]$title
#visualize
plotGraph(gm[[1]])


###################################################
### code chunk number 9: iSubpathwayMiner.Rnw:147-148
###################################################
summary(gm[[1]])


###################################################
### code chunk number 10: iSubpathwayMiner.Rnw:153-154
###################################################
print(gm[["00010"]],v=TRUE,e=TRUE,g=TRUE)


###################################################
### code chunk number 11: iSubpathwayMiner.Rnw:157-160
###################################################
#display a subgraph with 5 nodes.
sgm<-subgraph(gm[[1]],V(gm[[1]])[1:5])
print(sgm,g=TRUE,v=TRUE,e=TRUE)


###################################################
### code chunk number 12: iSubpathwayMiner.Rnw:168-170
###################################################
gm[[1]]$title
gm[[1]]$number


###################################################
### code chunk number 13: iSubpathwayMiner.Rnw:173-174
###################################################
V(gm[[1]])[2]$names


###################################################
### code chunk number 14: iSubpathwayMiner.Rnw:177-178
###################################################
get.vertex.attribute(gm[[1]],"names",2)


###################################################
### code chunk number 15: iSubpathwayMiner.Rnw:182-183
###################################################
V(gm[[1]])[2]$type


###################################################
### code chunk number 16: iSubpathwayMiner.Rnw:190-199
###################################################
#get indexes of nodes
index1<-V(gm[[1]])[V(gm[[1]])$names=="ec:4.1.2.13"]
index2<-V(gm[[1]])[V(gm[[1]])$names=="ec:1.2.1.59"]
#get shortest path
shortest.path<-get.shortest.paths(gm[[1]],index1,index2)
#display shortest path
shortest.path
#convert indexes to names
V(gm[[1]])[shortest.path[[1]]]$names


###################################################
### code chunk number 17: iSubpathwayMiner.Rnw:202-204
###################################################
index1<-V(gm[[1]])[V(gm[[1]])$names=="ec:4.1.2.13"]
betweenness(gm[[1]],index1)


###################################################
### code chunk number 18: iSubpathwayMiner.Rnw:209-215
###################################################
#node index value
as.integer(index1)
#direct display is not real node index value.
index1
#it is equal to the value of the "id" attribute.
index1$id


###################################################
### code chunk number 19: getNonMetabolicGraph1
###################################################
#get path
pathn<-paste(system.file(package="iSubpathwayMiner"),
"/localdata/kgml/non-metabolic/ko/",sep="")
pn<-getPathway(pathn,c("ko04010.xml","ko04020.xml"))
#Convert pathways to graphs
gn1<-getNonMetabolicGraph(pn)
#name of the first pathway
gn1[[1]]$title
#visualize
plotGraph(gn1[[1]])


###################################################
### code chunk number 20: getNonMetabolicGraph2
###################################################
#Convert pathways to graphs with ambiguous edges as deleted
gn2<-getNonMetabolicGraph(pn,ambiguousEdgeDirection="delete")


###################################################
### code chunk number 21: iSubpathwayMiner.Rnw:263-281
###################################################
##get metabolic pathway graphs
#get path of KGML files
path<-paste(system.file(package="iSubpathwayMiner"),
"/localdata/kgml/metabolic/ec/",sep="")
#convert metabolic pathways to graphs
gm<-getMetabolicGraph(getPathway(path,c("ec00010.xml")))
#show title of pathway graphs
sapply(gm,function(x) x$title)

##get non-metabolic pathway graphs
#get path
path1<-paste(system.file(package="iSubpathwayMiner"),
"/localdata/kgml/non-metabolic/ko/",sep="")
#convert non-metabolic pathways to graphs
gn<-getNonMetabolicGraph(getPathway(path1,c("ko04010.xml")),
ambiguousEdgeDirection="bi-directed")
#show title of pathway graphs
sapply(gn,function(x) x$title)


###################################################
### code chunk number 22: getUGraph
###################################################
#get undirected pathway graphs
g1<-getUGraph(gm,simpleGraph=TRUE)


###################################################
### code chunk number 23: iSubpathwayMiner.Rnw:296-297
###################################################
getOrgAndIdType()


###################################################
### code chunk number 24: mapNode
###################################################
#see the names attribute of nodes. 
V(gm[[1]])[1:10]$names
#get the organism-specific and idType-specific graph
g1<-mapNode(gm)
#see the names attribute of nodes in the new graph. 
#some node names are revised as NCBI-gene IDs 
V(g1[[1]])[1:10]$names


###################################################
### code chunk number 25: filterNode
###################################################
#We display them before nodes are filtered
V(gn[[1]])$type
#delete nodes with type="map"
g1<-filterNode(gn,nodeType=c("map"))
#The "map" nodes are deleted in the new graph. 
V(g1[[1]])$type


###################################################
### code chunk number 26: simplifyGraphGene
###################################################
#get graphs with enzymes as nodes and compounds as edges
g1<-simplifyGraph(gm,nodeType="geneProduct")
#see the names attribute of three edges
E(g1[[1]])[1:3]$names


###################################################
### code chunk number 27: simplifyGraphCompound
###################################################
#get graphs with compounds as nodes and enzymes as edges
g2<-simplifyGraph(gm,nodeType="compound")
#see the names attribute of three edges
E(g2[[1]])[1:3]$names


###################################################
### code chunk number 28: iSubpathwayMiner.Rnw:355-362
###################################################
#We firstly display node number before nodes are expanded
vcount(gn[[1]])
##expand nodes in Graphs
g1<-expandNode(gn)
#We can see change of node number in the new graph:
#node number after nodes are expanded
vcount(g1[[1]])


###################################################
### code chunk number 29: iSubpathwayMiner.Rnw:368-370
###################################################
#only expand nodes with type="enzyme" or "ortholog" in graphs
g2<-expandNode(gn,nodeType=c("ortholog","enzyme"))


###################################################
### code chunk number 30: iSubpathwayMiner.Rnw:378-379
###################################################
all(sapply(gm,is.simple))


###################################################
### code chunk number 31: mergeNode
###################################################
#get node number before merge
vcount(gm[[1]])
#merge nodes
g1<-mergeNode(gm,simple=FALSE)
#get node number after merge
vcount(g1[[1]])


###################################################
### code chunk number 32: combination1-1
###################################################
#get graphs with enzymes and compounds as nodes
g1<-filterNode(gm,nodeType=c("map"))
#visualize
plotGraph(g1[[1]])


###################################################
### code chunk number 33: combination1-2
###################################################
#get the undirected graphs with enzymes and compounds as nodes
g2<-filterNode(getUGraph(gm),nodeType=c("map"))


###################################################
### code chunk number 34: combination1-3
###################################################
#get graphs with enzymes and compounds as nodes
#And, each node only contains one enzyme/compound and 
#each enzyme/compound only appears once in the graph.
g3<-mergeNode(expandNode(filterNode(gm,nodeType=c("map"))))


###################################################
### code chunk number 35: combination1-4
###################################################
#get the undirected graphs with enzymes and compounds as nodes
#And, each node only contains one enzyme/compound and 
#each enzyme/compound only appears once in the graph.
g4<-mergeNode(expandNode(filterNode(getUGraph(gm),nodeType=c("map"))))


###################################################
### code chunk number 36: combination1-5
###################################################
#get graphs with KOs and compounds as nodes
g5<-filterNode(gn,nodeType=c("map"))


###################################################
### code chunk number 37: combination1-6
###################################################
#get the undirected graphs with KOs and compounds as nodes
g6<-filterNode(getUGraph(gn),nodeType=c("map"))


###################################################
### code chunk number 38: combination1-7
###################################################
#get graphs with KOs and compounds as nodes
#And, each node only contains a KO/compound and 
#each KO/compound only appears once in the graph.
g7<-mergeNode(expandNode(filterNode(gn,nodeType=c("map"))))


###################################################
### code chunk number 39: combination1-8
###################################################
#get the undirected graphs with KOs and compounds as nodes
#And, each node only contains a KO/compound and 
#each KO/compound only appears once in the graph.
g8<-mergeNode(expandNode(filterNode(getUGraph(gn),nodeType=c("map"))))


###################################################
### code chunk number 40: combination2-1
###################################################
#get graphs with enzymes as nodes and compounds as edges
g1<-simplifyGraph(filterNode(gm,nodeType=c("map")),nodeType="geneProduct")


###################################################
### code chunk number 41: combination2-2
###################################################
#get the undirected graphs with enzymes as nodes and compounds as edges
g2<-simplifyGraph(filterNode(getUGraph(gm),nodeType=c("map")),nodeType="geneProduct")


###################################################
### code chunk number 42: combination2-3
###################################################
#get graphs with enzymes as nodes and compounds as edges
#And, each node contains only one enzyme and each enzyme only appears once. 
g3<-mergeNode(expandNode(simplifyGraph(filterNode(gm,
nodeType=c("map")),nodeType="geneProduct")))


###################################################
### code chunk number 43: combination2-4
###################################################
#get undirected graphs with enzymes as nodes and compounds as edges.
#And, each node contains only one enzyme and each enzyme only appears once. 
g4<-mergeNode(expandNode(simplifyGraph(filterNode(getUGraph(gm),
nodeType=c("map")),nodeType="geneProduct")))


###################################################
### code chunk number 44: combination2-5
###################################################
#get graphs with KOs as nodes
g5<-simplifyGraph(filterNode(gn,nodeType=c("map")),nodeType="geneProduct")


###################################################
### code chunk number 45: combination2-6
###################################################
#get the undirected graphs with KOs as nodes
g6<-simplifyGraph(filterNode(getUGraph(gn),
nodeType=c("map")),nodeType="geneProduct")


###################################################
### code chunk number 46: combination2-7
###################################################
#get graphs with only KOs as nodes. And, each node contains 
#only a KO and each KO only appears once in the graph.
g7<-mergeNode(expandNode(simplifyGraph(filterNode(gn,
nodeType=c("map")),nodeType="geneProduct")))


###################################################
### code chunk number 47: combination2-8
###################################################
#get the undirected graphs with only KOs as nodes. And, each node contains 
#only a KO and each KO only appears once in the graph.
g8<-mergeNode(expandNode(simplifyGraph(filterNode(gn,
nodeType=c("map")),nodeType="geneProduct")))


###################################################
### code chunk number 48: combination3-1
###################################################
#The graph with compounds as nodes and enzymes as edges
g1<-simplifyGraph(filterNode(gm,nodeType=c("map")),nodeType="compound")


###################################################
### code chunk number 49: combination3-2
###################################################
#The undirected graph with compounds as nodes and enzymes as edges
g2<-simplifyGraph(filterNode(getUGraph(gm),nodeType=c("map")),nodeType="compound")


###################################################
### code chunk number 50: combination3-3
###################################################
#The graph with compounds as nodes and enzymes as edges
#Each node only contains a compound and each compound only appears once in the graph.
g3<-mergeNode(expandNode(simplifyGraph(filterNode(gm,
nodeType=c("map")),nodeType="compound")))


###################################################
### code chunk number 51: combination3-4
###################################################
#The undirected graph with compounds as nodes and enzymes as edges
#Each node only contains a compound and each compound only appears once in the graph.
g4<-mergeNode(expandNode(simplifyGraph(filterNode(getUGraph(gm),
nodeType=c("map")),nodeType="compound")))


###################################################
### code chunk number 52: combination4-1
###################################################
#get graphs with organism-specific genes as nodes and compounds as edges
g1<-mergeNode(expandNode(simplifyGraph(filterNode(mapNode(gm),
nodeType=c("map","enzyme")),nodeType="geneProduct")))


###################################################
### code chunk number 53: combination4-2
###################################################
#get the undirected graphs with organism-specific genes as nodes and compounds as edges
g2<-mergeNode(expandNode(simplifyGraph(filterNode(mapNode(getUGraph(gm)),
nodeType=c("map","enzyme")),nodeType="geneProduct")))


###################################################
### code chunk number 54: combination4-3
###################################################
#get graphs with organism-specific genes as nodes
g3<-mergeNode(expandNode(simplifyGraph(filterNode(mapNode(gn),
nodeType=c("map","ortholog")),nodeType="geneProduct")))


###################################################
### code chunk number 55: combination4-4
###################################################
#get the undirected graphs with organism-specific genes as nodes
g4<-mergeNode(expandNode(simplifyGraph(filterNode(mapNode(gn),
nodeType=c("map","ortholog")),nodeType="geneProduct")))


###################################################
### code chunk number 56: iSubpathwayMiner.Rnw:676-685
###################################################
#get path of KGML files
path<-paste(system.file(package="iSubpathwayMiner"),
"/localdata/kgml/metabolic/ec/",sep="")
#convert metabolic pathways to graphs with "map" node deleted
gmf<-filterNode(getMetabolicGraph(getPathway(path,c("ec00010.xml"))))
#show title of pathway graphs
sapply(gmf,function(x) x$title)
#convert metablic pathways to graphs with enzymes as nodes and compounds as edges
gmfs<-simplifyGraph(gmf,nodeType="geneProduct")


###################################################
### code chunk number 57: baseGraph2
###################################################
#visualize annotated graph
plotGraph(gmfs[[1]])


###################################################
### code chunk number 58: iSubpathwayMiner.Rnw:704-706
###################################################
#get degree of nodes
igraph::degree(gmfs[[1]],0)


###################################################
### code chunk number 59: iSubpathwayMiner.Rnw:709-711
###################################################
#see name of the first node
V(gmfs[[1]])[0]$names


###################################################
### code chunk number 60: iSubpathwayMiner.Rnw:716-720
###################################################
#get indexes of nodes
index1<-V(gmfs[[1]])[V(gmfs[[1]])$names=="ec:4.1.2.13"]
#get degree of node
igraph::degree(gmfs[[1]],index1)


###################################################
### code chunk number 61: iSubpathwayMiner.Rnw:725-727
###################################################
#Calculate betweenness of enzyme "ec:4.1.2.13".
betweenness(gmfs[[1]],index1)


###################################################
### code chunk number 62: iSubpathwayMiner.Rnw:732-734
###################################################
#Calculate the clustering coefficient of enzyme "ec:4.1.2.13".
igraph::transitivity(gmfs[[1]],type="local",vids=index1)


###################################################
### code chunk number 63: iSubpathwayMiner.Rnw:741-743
###################################################
#get the shortest path
shortest.path<-get.shortest.paths(gmf[[1]],0,1,mode="out")


###################################################
### code chunk number 64: iSubpathwayMiner.Rnw:746-750
###################################################
#see name of the first and second nodes
V(gmf[[1]])[0:1]$names
#see name of nodes in the shortest path
V(gmf[[1]])[shortest.path[[1]]]$names


###################################################
### code chunk number 65: iSubpathwayMiner.Rnw:756-765
###################################################
#get indexes of nodes
index1<-V(gmf[[1]])[V(gmf[[1]])$names=="ec:4.1.2.13"]
index2<-V(gmf[[1]])[V(gmf[[1]])$names=="ec:1.2.1.3"]
#get shortest path
shortest.path<-get.shortest.paths(gmf[[1]],index1,index2)
#display shortest path
shortest.path
#convert indexs to names
V(gmf[[1]])[shortest.path[[1]]]$names


###################################################
### code chunk number 66: iSubpathwayMiner.Rnw:771-773
###################################################
#degree distribution.
degree.distribution<-degree.distribution(gmfs[[1]])


###################################################
### code chunk number 67: iSubpathwayMiner.Rnw:777-779
###################################################
#get diameter
diameter(gmfs[[1]])


###################################################
### code chunk number 68: iSubpathwayMiner.Rnw:783-785
###################################################
#Calculate the clustering coefficient.
igraph::transitivity(gmfs[[1]])


###################################################
### code chunk number 69: iSubpathwayMiner.Rnw:789-791
###################################################
#Calculate the density.
graph.density(gmfs[[1]])


###################################################
### code chunk number 70: iSubpathwayMiner.Rnw:795-799
###################################################
#find modules.
wtc <- walktrap.community(gmfs[[1]])
module<-community.to.membership(gmfs[[1]], wtc$merges, steps=53)
module


###################################################
### code chunk number 71: iSubpathwayMiner.Rnw:802-803
###################################################
V(gmfs[[1]])[module$membership==0]$names


###################################################
### code chunk number 72: iSubpathwayMiner.Rnw:807-808
###################################################
modularity(gmfs[[1]], module$membership)


###################################################
### code chunk number 73: iSubpathwayMiner.Rnw:823-832
###################################################
#get pathway graphs with enzymes as nodes.
graphList<-getMetabolicECECGraph()
#get a set of genes
geneList<-getExample(geneNumber=1000,compoundNumber=0)
#topology-based pathway analysis
ann<-identifyTopo(geneList,graphList,type="gene",propertyName="degree")
result<-printTopo(ann)
#print a part of the result
result[1:5,]


###################################################
### code chunk number 74: TopologyPlotAnnGraphGene
###################################################
#visualize
plotAnnGraph("path:00562",graphList,ann)


###################################################
### code chunk number 75: iSubpathwayMiner.Rnw:865-874
###################################################
#get undirected pathway graphs with genes as nodes.
graphList<-getMetabolicGEGEUEMGraph(type="EC")
#get a set of genes
geneList<-getExample(geneNumber=1000,compoundNumber=0)
#topology-based pathway analysis
ann<-identifyTopo(geneList,graphList,type="gene",propertyName="clusteringCoefficient")
result<-printTopo(ann)
#print a part of the result
result[1:10,c(1,3,6:8)]


###################################################
### code chunk number 76: iSubpathwayMiner.Rnw:887-890
###################################################
##Convert all metabolic pathways to graphs.
metabolicEC<-get("metabolicEC",envir=k2ri)
graphList<-getMetabolicGraph(metabolicEC)


###################################################
### code chunk number 77: iSubpathwayMiner.Rnw:893-902
###################################################
##get a set of genes
geneList<-getExample(geneNumber=1000)
#annotate gene sets to pathway graphs 
#and identify significant pathway graphs
ann<-identifyGraph(geneList,graphList)
#convert ann to data.frame
result<-printGraph(ann)
#print a part of the results to screen
result[1:10,]


###################################################
### code chunk number 78: iSubpathwayMiner.Rnw:921-923
###################################################
#list of the result
ann[1]


###################################################
### code chunk number 79: iSubpathwayMiner.Rnw:928-929
###################################################
result[result[,1] %in% "path:00010",]


###################################################
### code chunk number 80: entirePlotAnnGraphGene
###################################################
#visualize
plotAnnGraph("path:00010",graphList,ann)


###################################################
### code chunk number 81: iSubpathwayMiner.Rnw:952-959
###################################################
#get a set of compounds
compoundList<-getExample(geneNumber=0,compoundNumber=100)
#annotate compound sets and identify significant pathways
ann<-identifyGraph(compoundList,graphList,type="compound")
result<-printGraph(ann)
#display a part of the result
result[1:5,c(1,3,4,5)]


###################################################
### code chunk number 82: iSubpathwayMiner.Rnw:965-973
###################################################
#get a set of compounds and genes
componentList<-getExample(geneNumber=1000,compoundNumber=100)
#annotate gene and compound sets to metabolic graphs 
#and identify significant graphs
ann<-identifyGraph(componentList,graphList,type="gene_compound")
result<-printGraph(ann)
#display a part of results
result[1:5,c(1,3,4,5)]


###################################################
### code chunk number 83: iSubpathwayMiner.Rnw:980-994
###################################################
##Convert all metabolic pathways to graphs.
metabolicKO<-get("metabolicKO",envir=k2ri)
gm<-getMetabolicGraph(metabolicKO)
##Convert all non-metabolic pathways to graphs, 
nonMetabolicKO<-get("nonMetabolicKO",envir=k2ri)
gn<-getNonMetabolicGraph(nonMetabolicKO)
graphList<-c(gm,gn)
##get a set of genes
geneList<-getExample(geneNumber=1000,compoundNumber=0)
#annotate gene sets and identify significant pathways
ann<-identifyGraph(geneList,graphList,type="gene")
result<-printGraph(ann)
#display part of results
result[1:5,c(1,3,4,5)]


###################################################
### code chunk number 84: iSubpathwayMiner.Rnw:999-1009
###################################################
##Convert all metabolic pathways to graphs.
metabolicKO<-get("metabolicKO",envir=k2ri)
graphList<-getMetabolicGraph(metabolicKO)
##get a set of genes
geneList<-getExample(geneNumber=1000,compoundNumber=0)
#annotate gene sets and identify significant pathways
ann<-identifyGraph(geneList,graphList)
result<-printGraph(ann)
#display part of results
result[1:10,c(1,3,4,5)]


###################################################
### code chunk number 85: iSubpathwayMiner.Rnw:1019-1032
###################################################
##identify metabolic subpathways based on gene sets
#get the enzyme-enzyme pathway graphs
graphList<-getMetabolicECECUGraph()
#get all 4-clique subgraphs
subGraphList<-getKcSubiGraph(k=4,graphList)
#get a set of genes
geneList<-getExample(geneNumber=1000,compoundNumber=0)
#annotate gene sets to subpathways 
#and identify significant graphs
ann<-identifyGraph(geneList,subGraphList,type="gene")
result<-printGraph(ann)
#display a part of results
result[1:15,c(1,3,4,5)]


###################################################
### code chunk number 86: iSubpathwayMiner.Rnw:1036-1037
###################################################
result[result[,1] %in% "path:00010_3",]


###################################################
### code chunk number 87: kCliquePlotAnnGraphGene
###################################################
plotAnnGraph("path:00010_3",subGraphList,ann)


###################################################
### code chunk number 88: iSubpathwayMiner.Rnw:1066-1069
###################################################
path<-paste(system.file(package="iSubpathwayMiner"),
"/localdata/kgml/metabolic/ec/",sep="")
gm<-getMetabolicGraph(getPathway(path,c("ec00010.xml")))


###################################################
### code chunk number 89: keggStyle1
###################################################
#visualize
plotGraph(gm[[1]])


###################################################
### code chunk number 90: metabolicSymbol
###################################################
plotGraph(gm[[1]],vertex.label=getNodeLabel(gm[[1]],
type="currentId",displayNumber=1))


###################################################
### code chunk number 91: colorFrameGraphSet
###################################################
#add red frame to the enzyme "ec:4.1.2.13" 
vertex.frame.color<-ifelse(V(gm[[1]])$names=="ec:4.1.2.13","red","dimgray")
vertex.frame.color
#display new graph
plotGraph(gm[[1]],vertex.frame.color=vertex.frame.color)


###################################################
### code chunk number 92: newGraphSet
###################################################
#add green label to the comound "cpd:C00111" 
vertex.label.color<-ifelse(V(gm[[1]])$names=="cpd:C00111","green","dimgray")
#change node color
vertex.color<-sapply(V(gm[[1]])$type,function(x) if(x=="enzyme"){"pink"}
else if(x=="compound"){"yellow"} else{"white"})
#change node size
size<-ifelse(V(gm[[1]])$graphics_name=="Starch and sucrose metabolism",20,8)
#change a compound label
#font size
vertex.label.cex<-ifelse(V(gm[[1]])$names=="cpd:C00036",1.0,0.6)
#italic
vertex.label.font<-ifelse(V(gm[[1]])$names=="cpd:C00036",3,1)
#change y coordinate of an enzyme
layout<-getLayout(gm[[1]])
index<-V(gm[[1]])[V(gm[[1]])$names=="ec:4.1.1.32"]
layout[index+1,2]<-layout[index+1,2]+50
#display the new graph 
plotGraph(gm[[1]],vertex.frame.color=vertex.frame.color,
vertex.label.color=vertex.label.color,vertex.color=vertex.color,
vertex.size=size,vertex.size2=size,vertex.label.cex=vertex.label.cex,
vertex.label.font=vertex.label.font,layout=layout)


###################################################
### code chunk number 93: layoutrandom
###################################################
plotGraph(gm[[1]],layout=layout.random)


###################################################
### code chunk number 94: layoutcircle
###################################################
plotGraph(gm[[1]],layout=layout.circle)


###################################################
### code chunk number 95: iSubpathwayMiner.Rnw:1175-1183
###################################################
##Convert all metabolic pathways to graphs.
metabolicEC<-get("metabolicEC",envir=k2ri)
graphList<-getMetabolicGraph(metabolicEC)
##get a set of genes
geneList<-getExample(geneNumber=1000)
#annotate gene sets to pathway graphs 
#and identify significant pathway graphs
ann<-identifyGraph(geneList,graphList)


###################################################
### code chunk number 96: entirePlotAnnGraphGeneV
###################################################
#visualize
plotAnnGraph("path:00010",graphList,ann)


###################################################
### code chunk number 97: entirePlotAnnGraphGeneV
###################################################
#visualize
plotAnnGraph("path:00010",graphList,ann,gotoKEGG=TRUE)


###################################################
### code chunk number 98: iSubpathwayMiner.Rnw:1211-1212
###################################################
write.graph(gm[[1]], "ec00010.txt", "gml")


###################################################
### code chunk number 99: iSubpathwayMiner.Rnw:1216-1218
###################################################
##data in environment variable k2ri
ls(k2ri)


###################################################
### code chunk number 100: iSubpathwayMiner.Rnw:1222-1224
###################################################
#get all metabolic pathway data
metabolicEC<-get("metabolicEC",envir=k2ri)


###################################################
### code chunk number 101: iSubpathwayMiner.Rnw:1230-1231
###################################################
getOrgAndIdType()


###################################################
### code chunk number 102: iSubpathwayMiner.Rnw:1238-1240 (eval = FALSE)
###################################################
## path<-paste(system.file(package="iSubpathwayMiner"),"/localdata",sep="")
## updateOrgAndIdType("sce","sgd-sce",path)


###################################################
### code chunk number 103: iSubpathwayMiner.Rnw:1253-1254 (eval = FALSE)
###################################################
## saveK2ri("sce_sgd-sce.rda")


###################################################
### code chunk number 104: iSubpathwayMiner.Rnw:1259-1260 (eval = FALSE)
###################################################
## loadK2ri("sce_sgd-sce.rda")


###################################################
### code chunk number 105: sessionInfo
###################################################
sessionInfo()


